==> igloo_0_1_5.tar.tgz: igloo_0_1_5/igloo/language/1/barnraiser_01/common.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

//MENU
$lang['menu_latest'] = 							"latest";
$lang['menu_blog'] = 							"blogs";
$lang['menu_library'] = 						"wiki";
$lang['menu_forum_subject'] = 					"discussions";
$lang['menu_polls'] = 							"polls";
$lang['menu_channels'] =						"channels";
$lang['menu_files'] =							"files";
$lang['menu_membership'] = 						"account";
$lang['menu_profile'] = 						"persona";
$lang['menu_bookmarks'] = 						"marks &amp; tips";
$lang['menu_publishing'] = 						"publishing";
$lang['menu_statistics'] = 						"statistics";
$lang['menu_recommended'] = 					"recommended";
$lang['menu_send_message'] = 					"send a message";
$lang['menu_structure'] = 						"structure";
$lang['menu_blocked_users'] = 					"blocked";
$lang['menu_network'] = 						"network";
$lang['menu_directory'] = 						"directory";
$lang['menu_invite'] = 							"invite";
$lang['menu_messages'] = 						"messages";
$lang['menu_schedule'] = 						"schedule";
$lang['menu_help'] = 							"help";
$lang['menu_intro'] = 							"introduction";
$lang['menu_user_list'] = 						"membership";
$lang['menu_newsletter'] = 						"newsletter";
$lang['menu_acs'] = 							"permissions";
$lang['menu_abuse_reports'] = 					"abuse reports";
$lang['menu_rsp'] = 							"publishing";
$lang['menu_my_tags'] = 						"tags";
$lang['menu_tag_mgmt'] = 						"tags";


//HEADER
$lang['hdr_comment_preview'] = 					"comment preview";
$lang['hdr_tag'] = 								"tags";
$lang['hdr_search'] = 							"search";
$lang['hdr_options'] =							"options";
$lang['hdr_comments'] = 						"comments";
$lang['hdr_add_comment'] = 						"add comment";


//A HREF TAGS (links)
$lang['href_login'] =							"login";
$lang['href_register'] =						"register";
$lang['href_about'] =							"about Igloo";
$lang['href_logoff'] =							"logoff";
$lang['href_splash'] = 							"Splash";
$lang['href_data'] = 							"Stuff";
$lang['href_messages'] =						"Messages";
$lang['href_me'] =								"Me";
$lang['href_shoutbox'] =						"shout!";
$lang['href_network'] = 						"People";
$lang['href_structure'] = 						"Structure";
$lang['href_report_abuse'] = 					"report abuse";
$lang['href_unrecommend_this'] =				"Remove tip";
$lang['href_watch_this'] =						"Mark this";
$lang['href_recommend_this'] =					"Tip this";
$lang['href_unwatch_this'] =					"Remove mark";
$lang['href_comments'] = 						"comments";
$lang['href_send_message'] = 					"send messsage";
$lang['href_visit_poll'] = 						"visit poll";


// SUB
$lang['sub_edit_again'] = 						"edit again";
$lang['sub_save'] = 							"save";
$lang['sub_save_go'] = 							"save and go";
$lang['sub_update_tag'] = 						"update my tags";
$lang['sub_preview'] = 							"preview";
$lang['sub_add'] = 								"add";
$lang['sub_delete'] = 							"delete";
$lang['sub_update'] = 							"update";
$lang['sub_check_spelling'] =					"spellcheck";


//META TAGS (this will appear in search engines)
$lang['meta_Description'] =						""; //add in a description for your node
$lang['meta_keywords'] = 						""; //add in up to 25 keywords (barnraiser, nodeX, place)
$lang['meta_OriginalPublicationDate'] =			"";//YYYY/MM/DD // //add in a publication date


// ERROR
$lang['err_no_comments'] = 						"Sorry, there are no comments available.";


//BODY TEXT
$lang['txt_page_title'] = 						"barnraiser &#47; Igloo &#47; demo";
$lang['txt_strap'] = 							"<a href=\"http://www.barnraiser.org/igloo/\">Igloo</a> (interest group glue) is <a href=\"http://www.fsf.org/\">free software</a> is created and maintained by <a href=\"http://www.barnraiser.org/\">Barnraiser</a>. We are dedicated to giving people the tools they need to share knowledge and advance society through social software. Please consider supporting us.";
$lang['txt_comment'] = 							"Comment";
$lang['txt_no_comment_allowed'] = 				"Sorry, this item is not open to receive your comments.";
$lang['txt_no_comment_allowed_login'] = 		"Please <a href='index.php'>login</a> or <a href='register.php'>register</a> to leave your comments.";
$lang['txt_from'] = 							"from";
$lang['txt_joined'] = 							"Joined";
$lang['txt_hometown'] = 						"Hometown";
$lang['txt_author'] =							"author";
$lang['txt_bookmarks'] =						"bookmarks";
$lang['txt_marked'] =							"marked";
$lang['txt_tipped'] =							"tipped";
$lang['txt_votes'] = 							"votes";
$lang['txt_comment_datetime'] =					"Comment date and time";
$lang['sub_check_spelling'] =					"Check Spelling";
$lang['txt_history'] = 							"history";
$lang['txt_degree_nw'] = 						"network";
$lang['txt_publish_all'] = 						"everyone";
$lang['txt_profile_nic'] = 						"nic";
$lang['txt_profile_session_status'] = 			"status";
$lang['txt_last_edited'] = 						"last edited";
$lang['txt_option_group'] = 					"latest from the group";
$lang['txt_option_network'] = 					"latest from my network";
$lang['txt_option_mark'] = 						"mark this";
$lang['txt_option_tip'] = 						"tip this";
$lang['txt_list_nav_start'] = 					"start";
$lang['txt_list_nav_end'] = 					"end";
$lang['txt_list_nav_prev'] = 					"previous";
$lang['txt_list_nav_next'] = 					"next";
$lang['txt_login_to_vote'] = 					"log in to vote";
$lang['txt_filenames'] = 						"files";
$lang['txt_wikipagenames'] = 					"wiki links";

//PROFILE ADDONS
// leave these blank if you do not want them to show in forms and on pages.
$lang['txt_profile_text1'] =					"Messenger";
$lang['txt_profile_text2'] =					"Yahoo ID";
$lang['txt_profile_text3'] =					"ICQ number";
$lang['txt_profile_text4'] = 					"Mobile phone";
$lang['txt_profile_text5'] = 					"Skype";
$lang['txt_profile_text6'] = 					"Job title";
$lang['txt_profile_text7'] = 					"";
$lang['txt_profile_text8'] = 					"";
$lang['txt_profile_text9'] = 					"";
$lang['txt_profile_text10'] = 					"";


// MESSAGES AND EMAIL
$lang['subject_noreply'] = 						"no reply";

?>

==> igloo_0_1_6.tar.tgz: igloo_0_1_6/igloo/language/1/barnraiser_01/common.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

//MENU
$lang['menu_latest'] = 							"featured";
$lang['menu_blog'] = 							"blogs";
$lang['menu_library'] = 						"wiki";
$lang['menu_forum_subject'] = 					"discussions";
$lang['menu_polls'] = 							"polls";
$lang['menu_channels'] =						"channels";
$lang['menu_files'] =							"files";
$lang['menu_membership'] = 						"account";
$lang['menu_profile'] = 						"persona";
$lang['menu_bookmarks'] = 						"marks &amp; tips";
$lang['menu_publishing'] = 						"publishing";
$lang['menu_statistics'] = 						"statistics";
$lang['menu_recommended'] = 					"recommended";
$lang['menu_send_message'] = 					"send a message";
$lang['menu_structure'] = 						"structure";
$lang['menu_blocked_users'] = 					"blocked";
$lang['menu_network'] = 						"network";
$lang['menu_directory'] = 						"directory";
$lang['menu_invite'] = 							"invite";
$lang['menu_messages'] = 						"messages";
$lang['menu_schedule'] = 						"schedule";
$lang['menu_help'] = 							"help";
$lang['menu_intro'] = 							"introduction";
$lang['menu_user_list'] = 						"membership";
$lang['menu_newsletter'] = 						"newsletter";
$lang['menu_acs'] = 							"permissions";
$lang['menu_abuse_reports'] = 					"abuse reports";
$lang['menu_rsp'] = 							"publishing";
$lang['menu_my_tags'] = 						"tags";
$lang['menu_tag_mgmt'] = 						"tags";
$lang['menu_overview'] = 						"overview";


//HEADER
$lang['hdr_comment_preview'] = 					"comment preview";
$lang['hdr_tag'] = 								"tags";
$lang['hdr_search'] = 							"search";
$lang['hdr_options'] =							"options";
$lang['hdr_comments'] = 						"comments";
$lang['hdr_add_comment'] = 						"add comment";


//A HREF TAGS (links)
$lang['href_login'] =							"login";
$lang['href_register'] =						"register";
$lang['href_about'] =							"about Igloo";
$lang['href_logoff'] =							"logoff";
$lang['href_splash'] = 							"Start";
$lang['href_data'] = 							"Group";
$lang['href_messages'] =						"Messages";
$lang['href_me'] =								"Me";
$lang['href_shoutbox'] =						"shout!";
$lang['href_network'] = 						"People";
$lang['href_structure'] = 						"Structure";
$lang['href_report_abuse'] = 					"report abuse";
$lang['href_unrecommend_this'] =				"remove tip";
$lang['href_watch_this'] =						"mark";
$lang['href_watch_this_notify'] = 				"mark &amp; track";
$lang['href_recommend_this'] =					"tip";
$lang['href_unwatch_this'] =					"remove mark";
$lang['href_comments'] = 						"comments";
$lang['href_send_message'] = 					"send messsage";
$lang['href_visit_poll'] = 						"visit poll";
$lang['href_edit'] = 							"edit";


// SUB
$lang['sub_edit_again'] = 						"edit again";
$lang['sub_save'] = 							"save";
$lang['sub_save_go'] = 							"save and go";
$lang['sub_update_tag'] = 						"update my tags";
$lang['sub_preview'] = 							"preview";
$lang['sub_add'] = 								"add";
$lang['sub_delete'] = 							"delete";
$lang['sub_update'] = 							"update";
$lang['sub_check_spelling'] =					"spellcheck";


//META TAGS (this will appear in search engines)
$lang['meta_Description'] =						""; //add in a description for your node
$lang['meta_keywords'] = 						""; //add in up to 25 keywords (barnraiser, nodeX, place)
$lang['meta_OriginalPublicationDate'] =			"";//YYYY/MM/DD // //add in a publication date


// ERROR
$lang['err_no_comments'] = 						"Sorry, there are no comments available.";


//BODY TEXT
$lang['txt_page_title'] = 						"your_title";
$lang['txt_strap'] = 							"<a href=\"http://www.barnraiser.org/igloo/\">Igloo</a> (interest group glue) is <a href=\"http://www.fsf.org/\">free software</a> is created and maintained by <a href=\"http://www.barnraiser.org/\">Barnraiser</a>. We are dedicated to giving people the tools they need to share knowledge and advance society through social software. Please consider supporting us.";
$lang['txt_comment'] = 							"Comment";
$lang['txt_no_comment_allowed'] = 				"Sorry, this item is not open to receive your comments.";
$lang['txt_no_comment_allowed_login'] = 		"Please <a href='index.php'>login</a> or <a href='register.php'>register</a> to leave your comments.";
$lang['txt_from'] = 							"from";
$lang['txt_joined'] = 							"Joined";
$lang['txt_hometown'] = 						"Hometown";
$lang['txt_author'] =							"author";
$lang['txt_bookmarks'] =						"bookmarks";
$lang['txt_marked'] =							"marked";
$lang['txt_tipped'] =							"tipped";
$lang['txt_item_options'] =						"item options";
$lang['txt_votes'] = 							"votes";
$lang['txt_comment_datetime'] =					"Comment date and time";
$lang['sub_check_spelling'] =					"Check Spelling";
$lang['txt_history'] = 							"history";
$lang['txt_degree_nw'] = 						"network";
$lang['txt_publish_all'] = 						"everyone";
$lang['txt_profile_nic'] = 						"nic";
$lang['txt_profile_session_status'] = 			"status";
$lang['txt_last_edited'] = 						"last edited";
$lang['txt_option_group'] = 					"latest from the group";
$lang['txt_option_network'] = 					"latest from my network";
$lang['txt_option_mark'] = 						"mark this";
$lang['txt_option_tip'] = 						"tip this";
$lang['txt_list_nav_start'] = 					"start";
$lang['txt_list_nav_end'] = 					"end";
$lang['txt_list_nav_prev'] = 					"previous";
$lang['txt_list_nav_next'] = 					"next";
$lang['txt_login_to_vote'] = 					"log in to vote";
$lang['txt_filenames'] = 						"files";
$lang['txt_wikipagenames'] = 					"wiki links";
$lang['txt_featured'] = 						"featured";


//PROFILE ADDONS
// leave these blank if you do not want them to show in forms and on pages.
$lang['txt_profile_text1'] =					"Messenger";
$lang['txt_profile_text2'] =					"Yahoo ID";
$lang['txt_profile_text3'] =					"ICQ number";
$lang['txt_profile_text4'] = 					"Mobile phone";
$lang['txt_profile_text5'] = 					"Skype";
$lang['txt_profile_text6'] = 					"Job title";
$lang['txt_profile_text7'] = 					"";
$lang['txt_profile_text8'] = 					"";
$lang['txt_profile_text9'] = 					"";
$lang['txt_profile_text10'] = 					"";


// MESSAGES AND EMAIL
$lang['subject_noreply'] = 						"no reply";

?>
